/*
 * Copyright MIT  <2012> <Francesco Trillini>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
 * to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE 
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package it.francescotrillini.opendatabase4j;

import java.util.ArrayList;
import java.util.List;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class Database extends SQLiteOpenHelper {
	
	private Context context;
	
	/**
	 * Constructor.
	 * @param context
	 * @param name
	 * @param version
	 */
	
	public Database(Context context, String name, int version) {
		
		super(context, name, null, version);
		
		this.context = context;
		
	}

	@Override
	public void onCreate(SQLiteDatabase db) {
		
		String query = "CREATE TABLE " + getDatabaseName() + "(" + "ID INTEGER PRIMARY KEY AUTOINCREMENT" + "," + "data INTEGER" + ")";
		
		db.execSQL(query);
		 
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {}
	
	/**
	 * Pushes the data into the database.
	 * @param data
	 */
	
	public void push(int data) {
		
		String query = "INSERT INTO " + getDatabaseName() + " (data) VALUES " + "(" + data + ")";
		
		SQLiteDatabase db = getWritableDatabase();
		
		db.execSQL(query);
		
	}
	
	/**
	 * Gets the data from the database.
	 * @return The data.
	 */
	
	public List<Integer> getData() {
		
		List<Integer> dataList = new ArrayList<Integer>();
		
		String query = "SELECT data FROM " + getDatabaseName();
		
		SQLiteDatabase db = getWritableDatabase();
		
		Cursor pointer = db.rawQuery(query, null);
		
		if(pointer.moveToFirst()) {
			
			do {
				
				// Gettin' em all
				dataList.add(pointer.getInt(pointer.getColumnIndex("data")));
				
			}
			
			while(pointer.moveToNext());
			
		}
		
		return dataList;
		
	}
	
	/**
	 * Destroys the entirely database.
	 */
	
	public void destroyDatabase() {
		
		context.deleteDatabase(getDatabaseName());
		
	}

}
